@@ -1,36 +1,39 @@
 use crate::pyo_utils::py_dict_to_map;
 use pyo3::prelude::*;
 use pyo3::types::PyDict;
+use pyo3_stub_gen::derive::*;
 use statsig_rust::{log_w, DynamicValue, StatsigUser};
 
 const TAG: &str = stringify!(StatsigUserPy);
 
+#[gen_stub_pyclass]
 #[pyclass(name = "StatsigUser")]
 pub struct StatsigUserPy {
     pub inner: StatsigUser,
 
-    #[pyo3(get)]
+    #[pyo3(get, set)]
     pub user_id: Option<String>,
-    #[pyo3(get)]
+    #[pyo3(get, set)]
     pub email: Option<String>,
-    #[pyo3(get)]
+    #[pyo3(get, set)]
     pub ip: Option<String>,
-    #[pyo3(get)]
+    #[pyo3(get, set)]
     pub country: Option<String>,
-    #[pyo3(get)]
+    #[pyo3(get, set)]
     pub locale: Option<String>,
-    #[pyo3(get)]
+    #[pyo3(get, set)]
     pub app_version: Option<String>,
-    #[pyo3(get)]
+    #[pyo3(get, set)]
     pub user_agent: Option<String>,
-    #[pyo3(get)]
+    #[pyo3(get, set)]
     pub custom: Option<Py<PyDict>>,
-    #[pyo3(get)]
+    #[pyo3(get, set)]
     pub custom_ids: Option<Py<PyDict>>,
-    #[pyo3(get)]
+    #[pyo3(get, set)]
     pub private_attributes: Option<Py<PyDict>>,
 }
 
+#[gen_stub_pymethods]
 #[pymethods]
 impl StatsigUserPy {
     #[new]
