@@ -134,11 +134,11 @@ impl Evaluator {
             let did_pass = evaluate_pass_percentage(ctx, rule, &spec.salt);
 
             if did_pass {
-                ctx.result.bool_value = rule.return_value.string_value != "false";
-                ctx.result.json_value = rule.return_value.json_value.clone();
+                ctx.result.bool_value = rule.return_value.get_bool() != Some(false);
+                ctx.result.json_value = rule.return_value.get_json();
             } else {
-                ctx.result.bool_value = spec.default_value.string_value == "true";
-                ctx.result.json_value = spec.default_value.json_value.clone();
+                ctx.result.bool_value = spec.default_value.get_bool() == Some(true);
+                ctx.result.json_value = spec.default_value.get_json();
             }
 
             ctx.result.rule_id = Some(&rule.id);
@@ -149,8 +149,8 @@ impl Evaluator {
             return Ok(Recognition::Recognized);
         }
 
-        ctx.result.bool_value = spec.default_value.string_value == "true";
-        ctx.result.json_value = spec.default_value.json_value.clone();
+        ctx.result.bool_value = spec.default_value.get_bool() == Some(true);
+        ctx.result.json_value = spec.default_value.get_json();
         ctx.result.rule_id = match spec.enabled {
             true => Some(&DEFAULT_RULE),
             false => Some(&DISABLED_RULE),
@@ -444,11 +444,22 @@ fn evaluate_nested_gate<'a>(
         return Ok(());
     };
 
-    ctx.prep_for_nested_evaluation()?;
-    let _ = Evaluator::evaluate(ctx, gate_name, &SpecType::Gate)?;
+    match ctx.nested_gate_memo.get(gate_name.as_str()) {
+        Some((previous_bool, previous_rule_id)) => {
+            ctx.result.bool_value = *previous_bool;
+            ctx.result.rule_id = *previous_rule_id;
+        }
+        None => {
+            ctx.prep_for_nested_evaluation()?;
+            let _ = Evaluator::evaluate(ctx, gate_name, &SpecType::Gate)?;
 
-    if ctx.result.unsupported {
-        return Ok(());
+            if ctx.result.unsupported {
+                return Ok(());
+            }
+
+            ctx.nested_gate_memo
+                .insert(gate_name, (ctx.result.bool_value, ctx.result.rule_id));
+        }
     }
 
     if !&gate_name.starts_with("segment:") {
