@@ -2,8 +2,6 @@ use crate::compression::compression_helper::{compress_data, get_compression_form
 use crate::event_logging_adapter::EventLoggingAdapter;
 use crate::log_event_payload::LogEventRequest;
 use crate::networking::{NetworkClient, NetworkError, RequestArgs};
-use crate::observability::ops_stats::{OpsStatsForInstance, OPS_STATS};
-use crate::observability::ErrorBoundaryEvent;
 use crate::statsig_metadata::StatsigMetadata;
 use crate::{log_d, StatsigErr, StatsigRuntime};
 use async_trait::async_trait;
@@ -24,7 +22,6 @@ const TAG: &str = stringify!(StatsigHttpEventLoggingAdapter);
 pub struct StatsigHttpEventLoggingAdapter {
     log_event_url: String,
     network: NetworkClient,
-    ops_stats: Arc<OpsStatsForInstance>,
 }
 
 impl StatsigHttpEventLoggingAdapter {
@@ -44,7 +41,6 @@ impl StatsigHttpEventLoggingAdapter {
         Self {
             log_event_url,
             network: NetworkClient::new(sdk_key, Some(headers), disable_network),
-            ops_stats: OPS_STATS.get_for_instance(sdk_key),
         }
     }
 
@@ -67,6 +63,10 @@ impl StatsigHttpEventLoggingAdapter {
                 "statsig-event-count".to_string(),
                 request.event_count.to_string(),
             ),
+            (
+                "statsig-retry-count".to_string(),
+                request.retries.to_string(),
+            ),
             ("Content-Encoding".to_owned(), compression_format.clone()),
             ("Content-Type".to_owned(), "application/json".to_owned()),
         ]);
@@ -80,22 +80,30 @@ impl StatsigHttpEventLoggingAdapter {
         };
 
         // Make request
-        let response_str = self
+        let response = self
             .network
             .post(
                 RequestArgs {
                     url: self.log_event_url.clone(),
-                    retries: 3,
                     headers: Some(headers),
                     accept_gzip_response: true,
-                    ..RequestArgs::default()
+                    ..RequestArgs::new()
                 },
                 Some(compressed),
             )
             .await
             .map_err(|err| StatsigErr::NetworkError(err, Some("Log event failure".into())))?;
+        let response_slice = match response.data {
+            Some(data) => data,
+            None => {
+                return Err(StatsigErr::NetworkError(
+                    NetworkError::RequestFailed,
+                    Some("Empty response from network".to_string()),
+                ));
+            }
+        };
 
-        serde_json::from_str::<LogEventResult>(&response_str)
+        serde_json::from_slice::<LogEventResult>(&response_slice)
             .map(|result| result.success != Some(false))
             .map_err(|e| {
                 StatsigErr::JsonParseError(stringify!(LogEventResult).to_string(), e.to_string())
@@ -114,18 +122,8 @@ impl EventLoggingAdapter for StatsigHttpEventLoggingAdapter {
         match self.send_events_over_http(&request).await {
             Ok(_) => Ok(true),
             Err(StatsigErr::NetworkError(NetworkError::DisableNetworkOn, _)) => Ok(false),
-            Err(e) => {
-                self.ops_stats.log_error(ErrorBoundaryEvent {
-                    exception: "LogEventFailed".to_string(),
-                    tag: "statsig::log_event_failed".to_string(),
-                    extra: Some(HashMap::from([(
-                        "eventCount".to_string(),
-                        request.event_count.to_string(),
-                    )])),
-                });
-                Err(e)
-            }
-        }
+            Err(e) => Err(e),
+        } //TODO: surface retryable code status for the logger to know if it should put back into the queue
     }
 
     async fn shutdown(&self) -> Result<(), StatsigErr> {
@@ -153,6 +151,7 @@ async fn test_event_logging() {
     let request = LogEventRequest {
         payload,
         event_count: 1,
+        retries: 0,
     };
 
     let result = adapter.log_events(request).await;
