@@ -1,6 +1,7 @@
 use crate::evaluation::evaluation_types::{AnyConfigEvaluation, GateEvaluation, LayerEvaluation};
 use crate::spec_types::Parameter;
-use crate::statsig_user_internal::{StatsigUserInternal, StatsigUserLoggable};
+use crate::user::{StatsigUserInternal, StatsigUserLoggable};
+
 use serde::{Deserialize, Serialize};
 use std::collections::HashMap;
 
@@ -30,7 +31,7 @@ impl InitializeResponse {
             time: 0,
             has_updates: false,
             hash_used: Default::default(),
-            user: StatsigUserLoggable::new(user),
+            user: user.to_loggable(),
             sdk_params: Default::default(),
             evaluated_keys: Default::default(),
             sdk_info: Default::default(),
