@@ -15,12 +15,25 @@ use super::ops_stats::OpsStatsEvent;
 
 static SDK_EXCEPTION_ENDPOINT: &str = "https://statsigapi.net/v1/sdk_exception";
 
+#[cfg(not(feature = "testing"))]
+fn get_sdk_exception_endpoint() -> String {
+    SDK_EXCEPTION_ENDPOINT.to_string()
+}
+
+#[cfg(feature = "testing")]
+fn get_sdk_exception_endpoint() -> String {
+    std::env::var("STATSIG_SDK_EXCEPTION_URL").unwrap_or(SDK_EXCEPTION_ENDPOINT.to_string())
+}
+
 #[derive(Clone, Serialize)]
 #[serde(rename_all = "camelCase")]
 pub struct ErrorBoundaryEvent {
     pub tag: String,
     pub exception: String,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub dedupe_key: Option<String>,
 
+    pub bypass_dedupe: bool,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub extra: Option<HashMap<String, String>>,
 }
@@ -32,28 +45,32 @@ pub struct SDKErrorsObserver {
     errors_aggregator: RwLock<HashMap<String, u32>>,
     network_client: NetworkClient,
     statsig_options_logging_copy: String,
+    sdk_exception_url: String,
 }
 
 impl SDKErrorsObserver {
     pub fn new(sdk_key: &str, options: &StatsigOptions) -> Self {
+        let mut headers = StatsigMetadata::get_constant_request_headers(sdk_key);
+        headers.insert("Content-Type".to_string(), "application/json".to_string());
         let options_logging_copy = serde_json::to_string(options).unwrap_or_default();
         SDKErrorsObserver {
-            network_client: NetworkClient::new(
-                sdk_key,
-                Some(StatsigMetadata::get_constant_request_headers(sdk_key)),
-                options.disable_network,
-            ),
+            network_client: NetworkClient::new(sdk_key, Some(headers), options.disable_network)
+                .mute_network_error_log(),
             errors_aggregator: RwLock::new(HashMap::new()),
             statsig_options_logging_copy: options_logging_copy,
+            sdk_exception_url: get_sdk_exception_endpoint(),
         }
     }
 
     async fn handle_eb_event(&self, eb_event: ErrorBoundaryEvent) {
-        let key = format!("{}:{}", eb_event.tag, eb_event.exception);
+        let key = eb_event
+            .dedupe_key
+            .clone()
+            .unwrap_or(format!("{}:{}", eb_event.tag, eb_event.exception));
         let mut write_guard = self.errors_aggregator.write().await;
         let count = write_guard.entry(key).or_default();
         *count += 1;
-        if *count > 1 {
+        if *count > 1 && !eb_event.bypass_dedupe {
             return;
         }
         self.log_exception(eb_event).await;
@@ -69,9 +86,9 @@ impl SDKErrorsObserver {
         }
         let body = serde_json::to_string_pretty(&body_obj).unwrap_or_default();
         let request_args = RequestArgs {
-            url: SDK_EXCEPTION_ENDPOINT.to_owned(),
+            url: self.sdk_exception_url.clone(),
             retries: 0,
-            ..RequestArgs::default()
+            ..RequestArgs::new()
         };
         let _ = self
             .network_client
