@@ -2,10 +2,8 @@ use crate::evaluation::evaluation_types::AnyEvaluation;
 use crate::global_configs::GlobalConfigs;
 use crate::hashing::HashUtil;
 use crate::hashset_with_ttl::HashSetWithTTL;
-use crate::statsig_user_internal::StatsigUserInternal;
 use crate::{DynamicValue, StatsigErr, StatsigRuntime};
 use serde::{Deserialize, Serialize};
-use std::collections::HashMap;
 use std::sync::Arc;
 use tokio::time::Duration;
 
@@ -92,7 +90,7 @@ impl SamplingProcessor {
 
     pub fn get_sampling_decision_and_details(
         &self,
-        user: &StatsigUserInternal,
+        user_sampling_key: &str,
         eval_result: Option<&AnyEvaluation>,
         parameter_name_for_layer: Option<&str>,
     ) -> SamplingDecision {
@@ -101,7 +99,7 @@ impl SamplingProcessor {
             None => return SamplingDecision::force_logged(),
         };
 
-        if self.should_skip_sampling(eval_result, &user.statsig_environment) {
+        if self.should_skip_sampling(eval_result) {
             return SamplingDecision::force_logged();
         }
 
@@ -118,8 +116,11 @@ impl SamplingProcessor {
         }
 
         let sampling_mode = self.get_sampling_mode();
-        let sampling_exposure_key =
-            self.compute_sampling_exposure_key(eval_result, user, parameter_name_for_layer);
+        let sampling_exposure_key = self.compute_sampling_exposure_key(
+            eval_result,
+            user_sampling_key,
+            parameter_name_for_layer,
+        );
 
         let (should_send_exposures, sampling_rate) =
             self.evaluate_exposure_sending(eval_result, &sampling_exposure_key);
@@ -154,7 +155,7 @@ impl SamplingProcessor {
     fn compute_sampling_exposure_key(
         &self,
         eval_result: &AnyEvaluation,
-        user: &StatsigUserInternal,
+        user_sampling_key: &str,
         parameter_name_for_layer: Option<&str>,
     ) -> String {
         let base_eval_res = eval_result.get_base_result();
@@ -165,13 +166,13 @@ impl SamplingProcessor {
                 eval.allocated_experiment_name.as_deref().unwrap_or("null"),
                 parameter_name_for_layer.unwrap_or("null"),
                 &base_eval_res.rule_id,
-                user,
+                user_sampling_key,
             ),
             _ => self.compute_sampling_key_for_gate_or_config(
                 &base_eval_res.name,
                 &base_eval_res.rule_id,
                 &eval_result.get_gate_bool_value(),
-                user,
+                user_sampling_key,
             ),
         }
     }
@@ -182,10 +183,9 @@ impl SamplingProcessor {
         name: &str,
         rule_id: &str,
         value: &bool,
-        user: &StatsigUserInternal,
+        user_sampling_key: &str,
     ) -> String {
-        let user_key = self.compute_user_key(user);
-        format!("n:{name};u:{user_key};r:{rule_id};v:{value}")
+        format!("n:{name};u:{user_sampling_key};r:{rule_id};v:{value}")
     }
 
     /// compute sampling key for layers
@@ -195,33 +195,9 @@ impl SamplingProcessor {
         experiment_name: &str,
         parameter_name: &str,
         rule_id: &str,
-        user: &StatsigUserInternal,
+        user_sampling_key: &str,
     ) -> String {
-        let user_key = self.compute_user_key(user);
-        format!("n:{layer_name};e:{experiment_name};p:{parameter_name};u:{user_key};r:{rule_id}")
-    }
-
-    fn compute_user_key(&self, user: &StatsigUserInternal) -> String {
-        let user_data = &user.user_data;
-
-        let mut user_key = format!(
-            "u:{};",
-            user_data
-                .user_id
-                .as_ref()
-                .and_then(|id| id.string_value.as_deref())
-                .unwrap_or("")
-        );
-
-        if let Some(custom_ids) = user_data.custom_ids.as_ref() {
-            for (key, val) in custom_ids {
-                if let Some(string_value) = &val.string_value {
-                    user_key.push_str(&format!("{key}:{string_value};"));
-                }
-            }
-        };
-
-        user_key
+        format!("n:{layer_name};e:{experiment_name};p:{parameter_name};u:{user_sampling_key};r:{rule_id}")
     }
 
     // -------------------------
@@ -262,11 +238,7 @@ impl SamplingProcessor {
         (true, None) // default to true, always send exposures, do NOT sample
     }
 
-    fn should_skip_sampling(
-        &self,
-        eval_result: &AnyEvaluation,
-        env: &Option<HashMap<String, DynamicValue>>,
-    ) -> bool {
+    fn should_skip_sampling(&self, eval_result: &AnyEvaluation) -> bool {
         let sampling_mode = self.get_sampling_mode();
 
         if matches!(sampling_mode, SamplingMode::None) {
@@ -289,21 +261,6 @@ impl SamplingProcessor {
             return true;
         }
 
-        // skip sampling if env is not in production
-        if env
-            .as_ref()
-            .and_then(|e| e.get("tier"))
-            .and_then(|tier| tier.string_value.as_deref())
-            != Some("production")
-        {
-            return true;
-        }
-
-        let rule_id = &eval_result.get_base_result().rule_id;
-        if rule_id.ends_with(":override") || rule_id.ends_with(":id_override") {
-            return true;
-        }
-
         false
     }
 
@@ -313,107 +270,32 @@ impl SamplingProcessor {
     }
 
     fn get_sampling_mode(&self) -> SamplingMode {
+        fn parse_sampling_mode(value: Option<&DynamicValue>) -> SamplingMode {
+            match value {
+                Some(value) => match value.string_value.as_deref() {
+                    Some("on") => SamplingMode::On,
+                    Some("shadow") => SamplingMode::Shadow,
+                    _ => SamplingMode::None,
+                },
+                None => SamplingMode::None,
+            }
+        }
+
         self.global_configs
-            .get_sdk_config_value("sampling_mode")
-            .and_then(|mode| mode.string_value)
-            .as_deref()
-            .map_or(SamplingMode::None, |mode_str| match mode_str {
-                "on" => SamplingMode::On,
-                "shadow" => SamplingMode::Shadow,
-                _ => SamplingMode::None,
-            })
+            .use_sdk_config_value("sampling_mode", parse_sampling_mode)
     }
 
     fn get_special_case_sampling_rate(&self) -> Option<u64> {
-        self.global_configs
-            .get_sdk_config_value("special_case_sampling_rate")
-            .and_then(|v| v.float_value)
-            .map(|rate| rate as u64)
-    }
-}
-
-#[cfg(test)]
-mod tests {
-    use super::*;
-    use crate::evaluation::evaluation_types::{BaseEvaluation, GateEvaluation};
-    use crate::{SpecStore, SpecsSource, SpecsUpdate, StatsigUser};
-    use serde_json::Value;
-    use std::fs;
-    use std::sync::LazyLock;
-
-    static GATE: LazyLock<GateEvaluation> = LazyLock::new(|| GateEvaluation {
-        base: BaseEvaluation {
-            name: "publish_to_all".to_string(),
-            rule_id: "rule_id".to_string(),
-            secondary_exposures: vec![],
-            sampling_info: Default::default(),
-        },
-        id_type: String::new(),
-        value: false,
-    });
-
-    fn create_mock_user() -> StatsigUserInternal {
-        let mut custom_ids = HashMap::new();
-        custom_ids.insert("k1".to_string(), "v1".to_string());
-        custom_ids.insert("k2".to_string(), "v2".to_string());
-
-        StatsigUserInternal {
-            user_data: StatsigUser::with_custom_ids(custom_ids),
-            statsig_environment: Some(HashMap::from([(
-                "tier".to_string(),
-                DynamicValue {
-                    string_value: Some("development".to_string()),
-                    ..Default::default()
-                },
-            )])),
+        fn parse_special_case_sampling_rate(value: Option<&DynamicValue>) -> Option<u64> {
+            match value {
+                Some(value) => value.float_value.map(|rate| rate as u64),
+                None => None,
+            }
         }
-    }
 
-    fn create_mock_evaluation_result() -> AnyEvaluation<'static> {
-        AnyEvaluation::FeatureGate(&GATE)
-    }
-
-    #[test]
-    fn test_should_skip_sampling() {
-        let file_path = "tests/data/dcs_with_sdk_configs.json";
-        let file_content = fs::read_to_string(file_path).expect("Unable to read file");
-        let json_data: Value = serde_json::from_str(&file_content).expect("Unable to parse JSON");
-
-        // Create the mocked SpecStore with sdk configs
-        let specs_update = SpecsUpdate {
-            data: json_data.to_string(),
-            source: SpecsSource::Network,
-            received_at: 2000,
-        };
-
-        let spec_store = SpecStore::default();
-        spec_store
-            .set_values(specs_update)
-            .expect("Set Specstore failed");
-
-        // initialize sampling processor
-        let runtime = StatsigRuntime::get_runtime();
-        let hashing = Arc::new(HashUtil::new());
-        let processor = SamplingProcessor::new(&runtime, hashing, "");
-
-        let mut test_user = create_mock_user();
-        let mock_evaluation_res = create_mock_evaluation_result();
-
-        // Should skip sampling in a non-production environment
-        let should_skip_sample =
-            processor.should_skip_sampling(&mock_evaluation_res, &test_user.statsig_environment);
-        assert!(should_skip_sample);
-
-        test_user.statsig_environment = Some(HashMap::from([(
-            "tier".to_string(),
-            DynamicValue {
-                string_value: Some("production".to_string()),
-                ..Default::default()
-            },
-        )]));
-        // should not skip sampling in a production environment
-        let should_skip_sample_2 =
-            processor.should_skip_sampling(&mock_evaluation_res, &test_user.statsig_environment);
-        assert!(!should_skip_sample_2);
+        self.global_configs.use_sdk_config_value(
+            "special_case_sampling_rate",
+            parse_special_case_sampling_rate,
+        )
     }
 }
