@@ -166,8 +166,8 @@ impl Statsig {
         let spec_store = Arc::new(SpecStore::new(
             sdk_key,
             hashing.sha256(&sdk_key.to_string()),
+            statsig_runtime.clone(),
             options.data_store.clone(),
-            Some(statsig_runtime.clone()),
         ));
 
         let environment = options
@@ -254,13 +254,6 @@ impl Statsig {
     }
 
     pub async fn shutdown_with_timeout(&self, timeout: Duration) -> Result<(), StatsigErr> {
-        let start = Instant::now();
-        let final_result = self.__shutdown_internal(timeout).await;
-        self.finalize_shutdown(timeout.saturating_sub(start.elapsed()));
-        final_result
-    }
-
-    pub async fn __shutdown_internal(&self, timeout: Duration) -> Result<(), StatsigErr> {
         log_d!(
             TAG,
             "Shutting down Statsig with timeout {}ms",
@@ -299,43 +292,10 @@ impl Statsig {
             }
         };
 
+        self.statsig_runtime.shutdown();
         shutdown_result
     }
 
-    pub fn sequenced_shutdown_prepare<F>(&self, callback: F)
-    where
-        F: FnOnce() + Send + 'static,
-    {
-        let event_logger = self.event_logger.clone();
-        let specs_adapter = self.specs_adapter.clone();
-        let runtime: Arc<StatsigRuntime> = self.statsig_runtime.clone();
-
-        self.statsig_runtime
-            .spawn("sequenced_shutdown_prep", |_shutdown_notify| async move {
-                let timeout = Duration::from_millis(1000);
-
-                let result = try_join!(
-                    event_logger.shutdown(timeout),
-                    specs_adapter.shutdown(timeout, &runtime)
-                );
-
-                match result {
-                    Ok(_) => {
-                        log_d!(TAG, "Shutdown successfully");
-                        callback();
-                    }
-                    Err(e) => {
-                        log_e!(TAG, "Shutdown failed: {:?}", e);
-                        callback();
-                    }
-                }
-            });
-    }
-
-    pub fn finalize_shutdown(&self, timeout: Duration) {
-        self.statsig_runtime.shutdown(timeout);
-    }
-
     async fn start_background_tasks(
         event_logger: Arc<EventLogger>,
         statsig_runtime: Arc<StatsigRuntime>,
@@ -583,7 +543,7 @@ impl Statsig {
             sdk_key: self.sdk_key.clone(),
             options: self.options.clone(),
             local_override_adapter: self.override_adapter.clone(),
-            spec_store_data: self.get_current_values(),
+            spec_store_data: self.spec_store.get_current_values(),
             error_observer: self.error_observer.clone(),
             diagnostics_observer: self.diagnostics_observer.clone(),
             spec_store: self.spec_store.clone(),
@@ -591,9 +551,9 @@ impl Statsig {
     }
 
     // todo: merge into get_context
+    #[deprecated(since = "0.1.0", note = "Use get_context instead")]
     pub fn get_current_values(&self) -> Option<SpecStoreData> {
-        // TODO better error handling here
-        Some(self.spec_store.data.read().ok()?.clone())
+        self.spec_store.get_current_values()
     }
 
     pub fn log_event(
