@@ -7,9 +7,10 @@ use crate::event_logging::layer_exposure::LayerExposure;
 use crate::sampling_processor::SamplingDecision;
 use crate::spec_types::Parameter;
 use crate::statsig_core_api_options::ParameterStoreEvaluationOptions;
-use crate::statsig_user_internal::StatsigUserInternal;
+use crate::user::StatsigUserLoggable;
 use crate::StatsigUser;
 use crate::{SamplingProcessor, Statsig};
+
 use serde::de::DeserializeOwned;
 use serde::{Deserialize, Serialize};
 use serde_json::{from_value, Value};
@@ -80,6 +81,7 @@ impl Experiment {
 pub struct Layer {
     pub name: String,
     pub rule_id: String,
+    pub id_type: String,
 
     pub group_name: Option<String>,
     pub details: EvaluationDetails,
@@ -87,7 +89,7 @@ pub struct Layer {
 
     pub __evaluation: Option<LayerEvaluation>,
     pub __value: HashMap<String, Value>,
-    pub __user: StatsigUserInternal,
+    pub __user: StatsigUserLoggable,
     pub __version: Option<u32>,
     pub __disable_exposure: bool,
     pub __override_config_name: Option<String>,
@@ -139,7 +141,7 @@ impl Layer {
             let layer_eval = self.__evaluation.as_ref();
 
             sampling_details = ptr.upgrade()?.get_sampling_decision_and_details(
-                &self.__user,
+                &self.__user.get_sampling_key(),
                 layer_eval.map(AnyEvaluation::from).as_ref(),
                 Some(param_name),
             );
@@ -227,10 +229,7 @@ impl ParameterStore<'_> {
     pub fn get_opt<T: DeserializeOwned>(&self, user: &StatsigUser, param_name: &str) -> Option<T> {
         let param = self.parameters.get(param_name)?;
         match param {
-            Parameter::StaticValue(static_value) => match from_value(static_value.value.clone()) {
-                Ok(value) => Some(value),
-                Err(_) => None,
-            },
+            Parameter::StaticValue(static_value) => from_value(static_value.value.clone()).ok(),
             Parameter::Gate(gate) => {
                 let res = self._statsig_ref.check_gate_with_options(
                     user,
@@ -241,10 +240,7 @@ impl ParameterStore<'_> {
                     true => gate.pass_value.clone(),
                     false => gate.fail_value.clone(),
                 };
-                match from_value(val) {
-                    Ok(value) => Some(value),
-                    Err(_) => None,
-                }
+                from_value(val).ok()
             }
             Parameter::DynamicConfig(dynamic_config) => {
                 let res = self._statsig_ref.get_dynamic_config_with_options(
