@@ -21,6 +21,7 @@ pub mod specs_adapter_tests {
             .send_stream_update(Ok(ConfigSpecResponse {
                 spec: "bg_sync_1".to_string(),
                 last_updated: 2,
+                zstd_dict_id: None,
             }))
             .await;
         data_store
@@ -31,8 +32,8 @@ pub mod specs_adapter_tests {
             .await;
 
         adapter.initialize(mock_listener.clone());
-        adapter.clone().start(&rt).await;
-        mock_listener.wait_for_next_update().await;
+        let _ = adapter.clone().start(&rt).await;
+        let _ = mock_listener.wait_for_next_update().await;
         // Use data store
         let received_update = mock_listener.force_get_most_recent_update();
         assert_eq!(
@@ -40,9 +41,9 @@ pub mod specs_adapter_tests {
             SpecsSource::Adapter("DataStore".to_string())
         );
         assert_eq!(received_update.data, "init_payload".to_string()); // examine time
-        adapter.clone().schedule_background_sync(&rt).await;
+        let _ = adapter.clone().schedule_background_sync(&rt).await;
 
-        mock_listener.wait_for_next_update().await;
+        let _ = mock_listener.wait_for_next_update().await;
         let received_update_2 = mock_listener.force_get_most_recent_update();
         assert_eq!(
             received_update_2.source,
@@ -56,19 +57,20 @@ pub mod specs_adapter_tests {
         use statsig_rust::SpecsAdapter;
 
         let rt = StatsigRuntime::get_runtime();
-        let (adapter, mock_proxy, data_store, mock_listener) =
+        let (adapter, mock_proxy, _data_store, mock_listener) =
             setup_datastore_and_streaming_combo().await;
 
         mock_proxy
             .send_stream_update(Ok(ConfigSpecResponse {
                 spec: "bg_sync_1".to_string(),
                 last_updated: 2,
+                zstd_dict_id: None,
             }))
             .await;
 
         adapter.initialize(mock_listener.clone());
-        adapter.clone().start(&rt).await;
-        mock_listener.wait_for_next_update().await;
+        let _ = adapter.clone().start(&rt).await;
+        let _ = mock_listener.wait_for_next_update().await;
         let received_update = mock_listener.force_get_most_recent_update();
         assert_eq!(
             received_update.source,
@@ -79,9 +81,10 @@ pub mod specs_adapter_tests {
             .send_stream_update(Ok(ConfigSpecResponse {
                 spec: "bg_sync_2".to_string(),
                 last_updated: 3,
+                zstd_dict_id: None,
             }))
             .await;
-        mock_listener.wait_for_next_update().await;
+        let _ = mock_listener.wait_for_next_update().await;
         let received_update_2 = mock_listener.force_get_most_recent_update();
         assert_eq!(
             received_update_2.source,
