@@ -41,6 +41,7 @@ pub mod specs_adapter_tests {
             .send_stream_update(Ok(ConfigSpecResponse {
                 spec: "bg_sync".to_string(),
                 last_updated: 123,
+                zstd_dict_id: None,
             }))
             .await;
 
@@ -66,12 +67,13 @@ pub mod specs_adapter_tests {
             .send_stream_update(Ok(ConfigSpecResponse {
                 spec: "first_sync".to_string(),
                 last_updated: 123,
+                zstd_dict_id: None,
             }))
             .await;
 
         adapter.clone().start(&statsig_rt).await.unwrap();
 
-        let a = mock_listener.wait_for_next_update().await;
+        let _ = mock_listener.wait_for_next_update().await;
 
         mock_proxy.clone().restart().await;
 
@@ -79,6 +81,7 @@ pub mod specs_adapter_tests {
             .send_stream_update(Ok(ConfigSpecResponse {
                 spec: "reconnected_sync".to_string(),
                 last_updated: 123,
+                zstd_dict_id: None,
             }))
             .await;
 
